__version__ = "1.8.1"
__title__ = "Spirit"
__description__ = "Optimizations and Dynamics Framework for atomistic Spin systems"
__uri__ = "https://spirit-code.github.io"
__license__ = "MIT"
__author__ = "Gideon Mueller"
__email__ = "g.mueller@fz-juelich.de"
